@@ -8,6 +8,7 @@
 # References:   1) PLUS - http://ns.useplus.org/
 #               2) PRISM - http://www.prismstandard.org/
 #               3) http://www.portfoliofaq.com/pfaq/v7mappings.htm
+#               4) http://www.iptc.org/IPTC4XMP/
 #               5) http://creativecommons.org/technology/xmp
 #                  --> changed to http://wiki.creativecommons.org/Companion_File_metadata_specification (2007/12/21)
 #               6) http://www.optimasc.com/products/fileid/xmp-extensions.pdf
@@ -22,6 +23,361 @@ use strict;
 use Image::ExifTool qw(:Utils);
 use Image::ExifTool::XMP;
 
+#------------------------------------------------------------------------------
+# IPTC Extensions version 1.3 (+ proposed video extensions)
+
+# IPTC Extension 1.0 structures
+my %sLocationDetails = (
+    STRUCT_NAME => 'LocationDetails',
+    NAMESPACE   => 'Iptc4xmpExt',
+    GROUPS      => { 2 => 'Location' },
+    Identifier  => { List => 'Bag', Namespace => 'xmp' },
+    City        => { },
+    CountryCode => { },
+    CountryName => { },
+    ProvinceState => { },
+    Sublocation => { },
+    WorldRegion => { },
+    LocationId  => { List => 'Bag' },
+    LocationName => { Writable => 'lang-alt' },
+    GPSLatitude  => { Namespace => 'exif', %latConv },
+    GPSLongitude => { Namespace => 'exif', %longConv },
+    GPSAltitude => {
+        Namespace => 'exif',
+        Writable => 'rational',
+        PrintConv => '$val =~ /^(inf|undef)$/ ? $val : "$val m"',
+        PrintConvInv => '$val=~s/\s*m$//;$val',
+    },
+);
+my %sCVTermDetails = (
+    STRUCT_NAME => 'CVTermDetails',
+    NAMESPACE   => 'Iptc4xmpExt',
+    CvTermId    => { },
+    CvTermName  => { Writable => 'lang-alt' },
+    CvId        => { },
+    CvTermRefinedAbout => { },
+);
+
+# IPTC video extensions
+my %sPublicationEvent = (
+    STRUCT_NAME => 'PublicationEvent',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Date        => { Groups => { 2 => 'Time' }, %dateTimeInfo },
+    Name        => { },
+    Identifier  => { },
+);
+my %sEntity = (
+    STRUCT_NAME => 'Entity',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Identifier  => { List => 'Bag', Namespace => 'xmp' },
+    Name        => { Writable => 'lang-alt' },
+);
+my %sEntityWithRole = (
+    STRUCT_NAME => 'EntityWithRole',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Identifier  => { List => 'Bag', Namespace => 'xmp' },
+    Name        => { Writable => 'lang-alt' },
+    Role        => { List => 'Bag' },
+);
+my %sFrameSize = (
+    STRUCT_NAME => 'FrameSize',
+    NAMESPACE   => 'Iptc4xmpExt',
+    WidthPixels  => { Writable => 'integer' },
+    HeightPixels => { Writable => 'integer' },
+);
+my %sRating = (
+    STRUCT_NAME => 'Rating',
+    NAMESPACE   => 'Iptc4xmpExt',
+    RatingValue         => { FlatName => 'Value' },
+    RatingSourceLink    => { FlatName => 'SourceLink' },
+    RatingScaleMinValue => { FlatName => 'ScaleMinValue' },
+    RatingScaleMaxValue => { FlatName => 'ScaleMaxValue' },
+    RatingValueLogoLink => { FlatName => 'ValueLogoLink' },
+    RatingRegion => {
+        FlatName => 'RatingRegion',
+        Struct => \%sLocationDetails,
+        List => 'Bag',
+    },
+);
+my %sEpisode = (
+    STRUCT_NAME => 'EpisodeOrSeason',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Name        => { },
+    Number      => { },
+    Identifier  => { },
+);
+my %sSeries = (
+    STRUCT_NAME => 'Series',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Name        => { },
+    Identifier  => { },
+);
+my %sTemporalCoverage = (
+    STRUCT_NAME => 'TemporalCoverage',
+    NAMESPACE   => 'Iptc4xmpExt',
+    tempCoverageFrom => { FlatName => 'From', %dateTimeInfo, Groups => { 2 => 'Time' } },
+    tempCoverageTo   => { FlatName => 'To',   %dateTimeInfo, Groups => { 2 => 'Time' } },
+);
+my %sQualifiedLink = (
+    STRUCT_NAME => 'QualifiedLink',
+    NAMESPACE   => 'Iptc4xmpExt',
+    Link        => { },
+    LinkQualifier => { },
+);
+my %sTextRegion = (
+    STRUCT_NAME => 'TextRegion',
+    NAMESPACE   => 'Iptc4xmpExt',
+    RegionText  => { },
+    Region      => { Struct => \%Image::ExifTool::XMP::sArea },
+);
+
+# IPTC Extension namespace properties (Iptc4xmpExt) (ref 4)
+%Image::ExifTool::XMP::iptcExt = (
+    %xmpTableDefaults,
+    GROUPS => { 1 => 'XMP-iptcExt', 2 => 'Author' },
+    NAMESPACE   => 'Iptc4xmpExt',
+    TABLE_DESC => 'XMP IPTC Extension',
+    NOTES => q{
+        IPTC Extension namespace tags.  The actual namespace prefix is
+        "Iptc4xmpExt", but ExifTool shortens this for the family 1 group name. (see
+        L<http://www.iptc.org/IPTC4XMP/>)
+    },
+    AboutCvTerm => {
+        Struct => \%sCVTermDetails,
+        List => 'Bag',
+    },
+    AboutCvTermCvId                 => { Flat => 1, Name => 'AboutCvTermCvId' },
+    AboutCvTermCvTermId             => { Flat => 1, Name => 'AboutCvTermId' },
+    AboutCvTermCvTermName           => { Flat => 1, Name => 'AboutCvTermName' },
+    AboutCvTermCvTermRefinedAbout   => { Flat => 1, Name => 'AboutCvTermRefinedAbout' },
+    AddlModelInfo   => { Name => 'AdditionalModelInformation' },
+    ArtworkOrObject => {
+        Struct => {
+            STRUCT_NAME => 'ArtworkOrObjectDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            AOCopyrightNotice => { },
+            AOCreator    => { List => 'Seq' },
+            AODateCreated=> { Groups => { 2 => 'Time' }, %dateTimeInfo },
+            AOSource     => { },
+            AOSourceInvNo=> { },
+            AOTitle      => { Writable => 'lang-alt' },
+            AOCurrentCopyrightOwnerName => { },
+            AOCurrentCopyrightOwnerId   => { },
+            AOCurrentLicensorName       => { },
+            AOCurrentLicensorId         => { },
+            AOCreatorId                 => { List => 'Seq' },
+            AOCircaDateCreated          => { Groups => { 2 => 'Time' } },
+            AOStylePeriod               => { List => 'Bag' },
+            AOSourceInvURL              => { },
+            AOContentDescription        => { Writable => 'lang-alt' },
+            AOContributionDescription   => { Writable => 'lang-alt' },
+            AOPhysicalDescription       => { Writable => 'lang-alt' },
+        },
+        List => 'Bag',
+    },
+    ArtworkOrObjectAOCopyrightNotice           => { Flat => 1, Name => 'ArtworkCopyrightNotice' },
+    ArtworkOrObjectAOCreator                   => { Flat => 1, Name => 'ArtworkCreator' },
+    ArtworkOrObjectAODateCreated               => { Flat => 1, Name => 'ArtworkDateCreated' },
+    ArtworkOrObjectAOSource                    => { Flat => 1, Name => 'ArtworkSource' },
+    ArtworkOrObjectAOSourceInvNo               => { Flat => 1, Name => 'ArtworkSourceInventoryNo' },
+    ArtworkOrObjectAOTitle                     => { Flat => 1, Name => 'ArtworkTitle' },
+    ArtworkOrObjectAOCurrentCopyrightOwnerName => { Flat => 1, Name => 'ArtworkCopyrightOwnerName' },
+    ArtworkOrObjectAOCurrentCopyrightOwnerId   => { Flat => 1, Name => 'ArtworkCopyrightOwnerID' },
+    ArtworkOrObjectAOCurrentLicensorName       => { Flat => 1, Name => 'ArtworkLicensorName' },
+    ArtworkOrObjectAOCurrentLicensorId         => { Flat => 1, Name => 'ArtworkLicensorID' },
+    ArtworkOrObjectAOCreatorId                 => { Flat => 1, Name => 'ArtworkCreatorID' },
+    ArtworkOrObjectAOCircaDateCreated          => { Flat => 1, Name => 'ArtworkCircaDateCreated' },
+    ArtworkOrObjectAOStylePeriod               => { Flat => 1, Name => 'ArtworkStylePeriod' },
+    ArtworkOrObjectAOSourceInvURL              => { Flat => 1, Name => 'ArtworkSourceInvURL' },
+    ArtworkOrObjectAOContentDescription        => { Flat => 1, Name => 'ArtworkContentDescription' },
+    ArtworkOrObjectAOContributionDescription   => { Flat => 1, Name => 'ArtworkContributionDescription' },
+    ArtworkOrObjectAOPhysicalDescription       => { Flat => 1, Name => 'ArtworkPhysicalDescription' },
+    CVterm => {
+        Name => 'ControlledVocabularyTerm',
+        List => 'Bag',
+        Notes => 'deprecated by version 1.2',
+    },
+    DigImageGUID            => { Name => 'DigitalImageGUID' },
+    DigitalSourcefileType   => {
+        Name => 'DigitalSourceFileType',
+        Notes => 'now deprecated -- replaced by DigitalSourceType',
+    },
+    DigitalSourceType       => { Name => 'DigitalSourceType' },
+    EmbdEncRightsExpr => {
+        Struct => {
+            STRUCT_NAME => 'EEREDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            EncRightsExpr       => { },
+            RightsExprEncType   => { },
+            RightsExprLangId    => { },
+        },
+        List => 'Bag',
+    },
+    EmbdEncRightsExprEncRightsExpr      => { Flat => 1, Name => 'EmbeddedEncodedRightsExpr' },
+    EmbdEncRightsExprRightsExprEncType  => { Flat => 1, Name => 'EmbeddedEncodedRightsExprType' },
+    EmbdEncRightsExprRightsExprLangId   => { Flat => 1, Name => 'EmbeddedEncodedRightsExprLangID' },
+    Event       => { Writable => 'lang-alt' },
+    IptcLastEdited => {
+        Name => 'IPTCLastEdited',
+        Groups => { 2 => 'Time' },
+        %dateTimeInfo,
+    },
+    LinkedEncRightsExpr => {
+        Struct => {
+            STRUCT_NAME => 'LEREDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            LinkedRightsExpr    => { },
+            RightsExprEncType   => { },
+            RightsExprLangId    => { },
+        },
+        List => 'Bag',
+    },
+    LinkedEncRightsExprLinkedRightsExpr  => { Flat => 1, Name => 'LinkedEncodedRightsExpr' },
+    LinkedEncRightsExprRightsExprEncType => { Flat => 1, Name => 'LinkedEncodedRightsExprType' },
+    LinkedEncRightsExprRightsExprLangId  => { Flat => 1, Name => 'LinkedEncodedRightsExprLangID' },
+    LocationCreated => {
+        Struct => \%sLocationDetails,
+        Groups => { 2 => 'Location' },
+        List => 'Bag',
+    },
+    LocationShown => {
+        Struct => \%sLocationDetails,
+        Groups => { 2 => 'Location' },
+        List => 'Bag',
+    },
+    MaxAvailHeight          => { Writable => 'integer' },
+    MaxAvailWidth           => { Writable => 'integer' },
+    ModelAge                => { List => 'Bag', Writable => 'integer' },
+    OrganisationInImageCode => { List => 'Bag' },
+    OrganisationInImageName => { List => 'Bag' },
+    PersonInImage           => { List => 'Bag' },
+    PersonInImageWDetails => {
+        Struct => {
+            STRUCT_NAME => 'PersonDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            PersonId    => { List => 'Bag' },
+            PersonName  => { Writable => 'lang-alt' },
+            PersonCharacteristic => {
+                Struct  => \%sCVTermDetails,
+                List    => 'Bag',
+            },
+            PersonDescription => { Writable => 'lang-alt' },
+        },
+        List => 'Bag',
+    },
+    PersonInImageWDetailsPersonId                               => { Flat => 1, Name => 'PersonInImageId' },
+    PersonInImageWDetailsPersonName                             => { Flat => 1, Name => 'PersonInImageName' },
+    PersonInImageWDetailsPersonCharacteristic                   => { Flat => 1, Name => 'PersonInImageCharacteristic' },
+    PersonInImageWDetailsPersonCharacteristicCvId               => { Flat => 1, Name => 'PersonInImageCvTermCvId' },
+    PersonInImageWDetailsPersonCharacteristicCvTermId           => { Flat => 1, Name => 'PersonInImageCvTermId' },
+    PersonInImageWDetailsPersonCharacteristicCvTermName         => { Flat => 1, Name => 'PersonInImageCvTermName' },
+    PersonInImageWDetailsPersonCharacteristicCvTermRefinedAbout => { Flat => 1, Name => 'PersonInImageCvTermRefinedAbout' },
+    PersonInImageWDetailsPersonDescription                      => { Flat => 1, Name => 'PersonInImageDescription' },
+    ProductInImage => {
+        Struct => {
+            STRUCT_NAME => 'ProductDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            ProductName => { Writable => 'lang-alt' },
+            ProductGTIN => { },
+            ProductDescription => { Writable => 'lang-alt' },
+        },
+        List => 'Bag',
+    },
+    ProductInImageProductName        => { Flat => 1, Name => 'ProductInImageName' },
+    ProductInImageProductGTIN        => { Flat => 1, Name => 'ProductInImageGTIN' },
+    ProductInImageProductDescription => { Flat => 1, Name => 'ProductInImageDescription' },
+    RegistryId => {
+        Name => 'RegistryID',
+        Struct => {
+            STRUCT_NAME => 'RegistryEntryDetails',
+            NAMESPACE   => 'Iptc4xmpExt',
+            RegItemId   => { },
+            RegOrgId    => { },
+            RegEntryRole=> { }, # (new in 1.3)
+        },
+        List => 'Bag',
+    },
+    RegistryIdRegItemId => { Flat => 1, Name => 'RegistryItemID' },
+    RegistryIdRegOrgId  => { Flat => 1, Name => 'RegistryOrganisationID' },
+    RegistryIdRegEntryRole => { Flat => 1, Name => 'RegistryEntryRole' },
+
+    # new Extension 1.3 properties
+    Genre           => { Groups => { 2 => 'Image' }, List => 'Bag', Struct => \%sCVTermDetails },
+
+    # new video properties (Oct 2016, ref Michael Steidl)
+    CircaDateCreated=> { Groups => { 2 => 'Time' } },
+    Episode         => { Groups => { 2 => 'Video' }, Struct => \%sEpisode },
+    ExternalMetadataLink => { Groups => { 2 => 'Other' }, List => 'Bag' },
+    FeedIdentifier  => { Groups => { 2 => 'Video' } },
+    PublicationEvent=> { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sPublicationEvent },
+    Rating          => {
+        Groups => { 2 => 'Other' },
+        Struct  => \%sRating,
+        List    => 'Bag',
+    },
+    ReleaseReady    => { Groups => { 2 => 'Other' }, Writable => 'boolean' },
+    Season          => { Groups => { 2 => 'Video' }, Struct => \%sEpisode },
+    Series          => { Groups => { 2 => 'Video' }, Struct => \%sSeries },
+    StorylineIdentifier => { Groups => { 2 => 'Video' }, List => 'Bag' },
+    StylePeriod     => { Groups => { 2 => 'Video' } },
+    TemporalCoverage=> { Groups => { 2 => 'Video' }, Struct => \%sTemporalCoverage },
+    WorkflowTag     => { Groups => { 2 => 'Video' }, Struct => \%sCVTermDetails },
+    DataOnScreen    => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sTextRegion },
+    Dopesheet       => { Groups => { 2 => 'Video' }, Writable => 'lang-alt' },
+    DopesheetLink   => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sQualifiedLink },
+    Headline        => { Groups => { 2 => 'Video' }, Writable => 'lang-alt', Avoid => 1 },
+    PersonHeard     => { Groups => { 2 => 'Audio' }, List => 'Bag', Struct => \%sEntity },
+    VideoShotType   => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sEntity },
+    EventExt        => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sEntity, Name => 'ShownEvent' },
+    Transcript      => { Groups => { 2 => 'Video' }, Writable => 'lang-alt' },
+    TranscriptLink  => { Groups => { 2 => 'Video' }, List => 'Bag', Struct => \%sQualifiedLink },
+    VisualColour    => {
+        Name => 'VisualColor',
+        Groups => { 2 => 'Video' },
+        PrintConv => {
+            'bw-monochrome' => 'Monochrome',
+            'colour'        => 'Color',
+        },
+    },
+    Contributor     => { List => 'Bag', Struct => \%sEntityWithRole },
+    CopyrightYear   => { Groups => { 2 => 'Time' },  Writable => 'integer' },
+    Creator         => { List => 'Bag', Struct => \%sEntityWithRole },
+    SupplyChainSource => { Groups => { 2 => 'Other' }, List => 'Bag', Struct => \%sEntity },
+    audioBitRate    => { Groups => { 2 => 'Audio' }, Writable => 'integer', Name => 'AudioBitrate' },
+    audioBitRateMode=> {
+        Name => 'AudioBitrateMode',
+        Groups => { 2 => 'Audio' },
+        PrintConv => {
+            fixed => 'Fixed',
+            variable => 'Variable',
+        },
+    },
+    audioChannelCount       => { Groups => { 2 => 'Audio' }, Writable => 'integer' },
+    videoDisplayAspectRatio => { Groups => { 2 => 'Audio' }, Writable => 'rational' },
+    ContainerFormat         => { Groups => { 2 => 'Video' }, Struct => \%sEntity },
+    StreamReady => {
+        Groups => { 2 => 'Video' },
+        PrintConv => {
+            true => 'True',
+            false => 'False',
+            unknown => 'Unknown',
+        },
+    },
+    videoBitRate     => { Groups => { 2 => 'Video' }, Writable => 'integer', Name => 'VideoBitrate' },
+    videoBitRateMode => {
+        Name => 'VideoBitrateMode',
+        Groups => { 2 => 'Video' },
+        PrintConv => {
+            fixed => 'Fixed',
+            variable => 'Variable',
+        },
+    },
+    videoEncodingProfile => { Groups => { 2 => 'Video' } },
+    videoStreamsCount    => { Groups => { 2 => 'Video' }, Writable => 'integer' },
+);
+
+#------------------------------------------------------------------------------
+
 # xmpDM structure definitions
 my %sCuePointParam = (
     STRUCT_NAME => 'CuePointParam',
@@ -276,7 +632,7 @@ my %sTimecode = (
             'CCIR-709' => 'CCIR-709',
         },
     },
-    videoCompressor     => { },
+    videoCompressor => { },
     videoFieldOrder => {
         PrintConv => {
             Upper => 'Upper',
@@ -284,9 +640,9 @@ my %sTimecode = (
             Progressive => 'Progressive',
         },
     },
-    videoFrameRate      => { Writable => 'real' },
-    videoFrameSize      => { Struct => \%sDimensions },
-    videoModDate        => { Groups => { 2 => 'Time' }, %dateTimeInfo },
+    videoFrameRate  => { Writable => 'real' },
+    videoFrameSize  => { Struct => \%sDimensions },
+    videoModDate    => { Groups => { 2 => 'Time' }, %dateTimeInfo },
     videoPixelAspectRatio => { Writable => 'rational' },
     videoPixelDepth => {
         PrintConv => {
@@ -300,316 +656,6 @@ my %sTimecode = (
     },
 );
 
-#------------------------------------------------------------------------------
-# PLUS (Picture Licensing Universal System)
-
-# PLUS vocabulary conversions
-my %plusVocab = (
-    ValueConv => '$val =~ s{http://ns.useplus.org/ldf/vocab/}{}; $val',
-    ValueConvInv => '"http://ns.useplus.org/ldf/vocab/$val"',
-);
-
-# PLUS License Data Format 1.2.1 structures
-# (this seems crazy to me -- why did they define different ID/Name structures
-#  for each field rather than just re-using the same structure?)
-my %plusLicensee = (
-    STRUCT_NAME => 'Licensee',
-    NAMESPACE => 'plus',
-    # all "rdf:type" properties removed in version 1.2.1
-    # (idiots.  Why did they put them there in the first place? -- it required
-    # a special patch for ExifTool to support these, and now they are gone!)
-  # TYPE => 'plus:LicenseeDetail', (removed in 1.2.1)
-    LicenseeID  => { },
-    LicenseeName=> { },
-);
-my %plusEndUser = (
-    STRUCT_NAME => 'EndUser',
-    NAMESPACE   => 'plus',
-  # TYPE => 'plus:EndUserDetail', (removed in 1.2.1)
-    EndUserID   => { },
-    EndUserName => { },
-);
-my %plusLicensor = (
-    STRUCT_NAME => 'Licensor',
-    NAMESPACE   => 'plus',
-  # TYPE => 'plus:LicensorDetail', (removed in 1.2.1)
-    LicensorID              => { },
-    LicensorName            => { },
-    LicensorStreetAddress   => { },
-    LicensorExtendedAddress => { },
-    LicensorCity            => { },
-    LicensorRegion          => { },
-    LicensorPostalCode      => { },
-    LicensorCountry         => { },
-    LicensorTelephoneType1  => {
-        %plusVocab,
-        PrintConv => {
-            'work'  => 'Work',
-            'cell'  => 'Cell',
-            'fax'   => 'FAX',
-            'home'  => 'Home',
-            'pager' => 'Pager',
-        },
-    },
-    LicensorTelephone1      => { },
-    LicensorTelephoneType2  => {
-        %plusVocab,
-        PrintConv => {
-            'work'  => 'Work',
-            'cell'  => 'Cell',
-            'fax'   => 'FAX',
-            'home'  => 'Home',
-            'pager' => 'Pager',
-        },
-    },
-    LicensorTelephone2  => { },
-    LicensorEmail       => { },
-    LicensorURL         => { },
-);
-my %plusCopyrightOwner = (
-    STRUCT_NAME => 'CopyrightOwner',
-    NAMESPACE   => 'plus',
-  # TYPE        => 'plus:CopyrightOwnerDetail', (removed in 1.2.1)
-    CopyrightOwnerID    => { },
-    CopyrightOwnerName  => { },
-);
-my %plusImageCreator = (
-    STRUCT_NAME => 'ImageCreator',
-    NAMESPACE   => 'plus',
-  # TYPE        => 'plus:ImageCreatorDetail', (removed in 1.2.1)
-    ImageCreatorID      => { },
-    ImageCreatorName    => { },
-);
-my %plusImageSupplier = (
-    STRUCT_NAME => 'ImageSupplier',
-    NAMESPACE   => 'plus',
-  # TYPE        => 'plus:ImageSupplierDetail', (removed in 1.2.1)
-    ImageSupplierID     => { },
-    ImageSupplierName   => { },
-);
-
-# PLUS License Data Format 1.2.0 (plus) (ref 1)
-%Image::ExifTool::XMP::plus = (
-    %xmpTableDefaults,
-    GROUPS => { 0 => 'XMP', 1 => 'XMP-plus', 2 => 'Author' },
-    NAMESPACE => 'plus',
-    NOTES => q{
-        PLUS License Data Format 1.2.1 namespace tags.  Note that all
-        controlled-vocabulary tags in this table (ie. tags with a fixed set of
-        values) have raw values which begin with "http://ns.useplus.org/ldf/vocab/",
-        but to reduce clutter this prefix has been removed from the values shown
-        below.  (see L<http://ns.useplus.org/>)
-    },
-    Version  => { Name => 'PLUSVersion' },
-    Licensee => {
-        FlatName => '',
-        Struct => \%plusLicensee,
-        List => 'Seq',
-    },
-    EndUser => {
-        FlatName => '',
-        Struct => \%plusEndUser,
-        List => 'Seq',
-    },
-    Licensor => {
-        FlatName => '',
-        Struct => \%plusLicensor,
-        List => 'Seq',
-    },
-    LicensorNotes               => { Writable => 'lang-alt' },
-    MediaSummaryCode            => { },
-    LicenseStartDate            => { %dateTimeInfo, Groups => { 2 => 'Time'} },
-    LicenseEndDate              => { %dateTimeInfo, Groups => { 2 => 'Time'} },
-    MediaConstraints            => { Writable => 'lang-alt' },
-    RegionConstraints           => { Writable => 'lang-alt' },
-    ProductOrServiceConstraints => { Writable => 'lang-alt' },
-    ImageFileConstraints => {
-        List => 'Bag',
-        %plusVocab,
-        PrintConv => {
-            'IF-MFN' => 'Maintain File Name',
-            'IF-MID' => 'Maintain ID in File Name',
-            'IF-MMD' => 'Maintain Metadata',
-            'IF-MFT' => 'Maintain File Type',
-        },
-    },
-    ImageAlterationConstraints => {
-        List => 'Bag',
-        %plusVocab,
-        PrintConv => {
-            'AL-CRP' => 'No Cropping',
-            'AL-FLP' => 'No Flipping',
-            'AL-RET' => 'No Retouching',
-            'AL-CLR' => 'No Colorization',
-            'AL-DCL' => 'No De-Colorization',
-            'AL-MRG' => 'No Merging',
-        },
-    },
-    ImageDuplicationConstraints => {
-        %plusVocab,
-        PrintConv => {
-            'DP-NDC' => 'No Duplication Constraints',
-            'DP-LIC' => 'Duplication Only as Necessary Under License',
-            'DP-NOD' => 'No Duplication',
-        },
-    },
-    ModelReleaseStatus => {
-        %plusVocab,
-        PrintConv => {
-            'MR-NON' => 'None',
-            'MR-NAP' => 'Not Applicable',
-            'MR-UMR' => 'Unlimited Model Releases',
-            'MR-LMR' => 'Limited or Incomplete Model Releases',
-        },
-    },
-    ModelReleaseID      => { List => 'Bag' },
-    MinorModelAgeDisclosure => {
-        %plusVocab,
-        PrintConv => {
-            'AG-UNK' => 'Age Unknown',
-            'AG-A25' => 'Age 25 or Over',
-            'AG-A24' => 'Age 24',
-            'AG-A23' => 'Age 23',
-            'AG-A22' => 'Age 22',
-            'AG-A21' => 'Age 21',
-            'AG-A20' => 'Age 20',
-            'AG-A19' => 'Age 19',
-            'AG-A18' => 'Age 18',
-            'AG-A17' => 'Age 17',
-            'AG-A16' => 'Age 16',
-            'AG-A15' => 'Age 15',
-            'AG-U14' => 'Age 14 or Under',
-        },
-    },
-    PropertyReleaseStatus => {
-        %plusVocab,
-        PrintConv => {
-            'PR-NON' => 'None',
-            'PR-NAP' => 'Not Applicable',
-            'PR-UPR' => 'Unlimited Property Releases',
-            'PR-LPR' => 'Limited or Incomplete Property Releases',
-        },
-    },
-    PropertyReleaseID  => { List => 'Bag' },
-    OtherConstraints   => { Writable => 'lang-alt' },
-    CreditLineRequired => {
-        %plusVocab,
-        PrintConv => {
-            'CR-NRQ' => 'Not Required',
-            'CR-COI' => 'Credit on Image',
-            'CR-CAI' => 'Credit Adjacent To Image',
-            'CR-CCA' => 'Credit in Credits Area',
-        },
-    },
-    AdultContentWarning => {
-        %plusVocab,
-        PrintConv => {
-            'CW-NRQ' => 'Not Required',
-            'CW-AWR' => 'Adult Content Warning Required',
-            'CW-UNK' => 'Unknown',
-        },
-    },
-    OtherLicenseRequirements    => { Writable => 'lang-alt' },
-    TermsAndConditionsText      => { Writable => 'lang-alt' },
-    TermsAndConditionsURL       => { },
-    OtherConditions             => { Writable => 'lang-alt' },
-    ImageType => {
-        %plusVocab,
-        PrintConv => {
-            'TY-PHO' => 'Photographic Image',
-            'TY-ILL' => 'Illustrated Image',
-            'TY-MCI' => 'Multimedia or Composited Image',
-            'TY-VID' => 'Video',
-            'TY-OTR' => 'Other',
-        },
-    },
-    LicensorImageID     => { },
-    FileNameAsDelivered => { },
-    ImageFileFormatAsDelivered => {
-        %plusVocab,
-        PrintConv => {
-            'FF-JPG' => 'JPEG Interchange Formats (JPG, JIF, JFIF)',
-            'FF-TIF' => 'Tagged Image File Format (TIFF)',
-            'FF-GIF' => 'Graphics Interchange Format (GIF)',
-            'FF-RAW' => 'Proprietary RAW Image Format',
-            'FF-DNG' => 'Digital Negative (DNG)',
-            'FF-EPS' => 'Encapsulated PostScript (EPS)',
-            'FF-BMP' => 'Windows Bitmap (BMP)',
-            'FF-PSD' => 'Photoshop Document (PSD)',
-            'FF-PIC' => 'Macintosh Picture (PICT)',
-            'FF-PNG' => 'Portable Network Graphics (PNG)',
-            'FF-WMP' => 'Windows Media Photo (HD Photo)',
-            'FF-OTR' => 'Other',
-        },
-    },
-    ImageFileSizeAsDelivered => {
-        %plusVocab,
-        PrintConv => {
-            'SZ-U01' => 'Up to 1 MB',
-            'SZ-U10' => 'Up to 10 MB',
-            'SZ-U30' => 'Up to 30 MB',
-            'SZ-U50' => 'Up to 50 MB',
-            'SZ-G50' => 'Greater than 50 MB',
-        },
-    },
-    CopyrightStatus => {
-        %plusVocab,
-        PrintConv => {
-            'CS-PRO' => 'Protected',
-            'CS-PUB' => 'Public Domain',
-            'CS-UNK' => 'Unknown',
-        },
-    },
-    CopyrightRegistrationNumber => { },
-    FirstPublicationDate        => { %dateTimeInfo, Groups => { 2 => 'Time'} },
-    CopyrightOwner => {
-        FlatName => '',
-        Struct => \%plusCopyrightOwner,
-        List => 'Seq',
-    },
-    CopyrightOwnerImageID   => { },
-    ImageCreator => {
-        FlatName => '',
-        Struct => \%plusImageCreator,
-        List => 'Seq',
-    },
-    ImageCreatorImageID     => { },
-    ImageSupplier => {
-        FlatName => '',
-        Struct => \%plusImageSupplier,
-        List => 'Seq',
-    },
-    ImageSupplierImageID    => { },
-    LicenseeImageID         => { },
-    LicenseeImageNotes      => { Writable => 'lang-alt' },
-    OtherImageInfo          => { Writable => 'lang-alt' },
-    LicenseID               => { },
-    LicensorTransactionID   => { List => 'Bag' },
-    LicenseeTransactionID   => { List => 'Bag' },
-    LicenseeProjectReference=> { List => 'Bag' },
-    LicenseTransactionDate  => { %dateTimeInfo, Groups => { 2 => 'Time'} },
-    Reuse => {
-        %plusVocab,
-        PrintConv => {
-            'RE-REU' => 'Repeat Use',
-            'RE-NAP' => 'Not Applicable',
-        },
-    },
-    OtherLicenseDocuments   => { List => 'Bag' },
-    OtherLicenseInfo        => { Writable => 'lang-alt' },
-    # Note: these are Bag's of lang-alt lists -- a nested list tag!
-    Custom1     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom2     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom3     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom4     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom5     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom6     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom7     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom8     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom9     => { List => 'Bag', Writable => 'lang-alt' },
-    Custom10    => { List => 'Bag', Writable => 'lang-alt' },
-);
-
 #------------------------------------------------------------------------------
 # PRISM
 #
@@ -1153,6 +1199,14 @@ my %sSubVersion = (
         Notes => 'newer version of XML raw processing settings',
         Binary => 1,
     },
+    # more tags (ref forum6840)
+    FixtureIdentifier   => { Avoid => 1 },
+    EditStatus          => { Avoid => 1 },
+    ReleaseDate         => { Avoid => 1 },
+    ReleaseTime         => { Avoid => 1 },
+    OriginatingProgram  => { Avoid => 1 },
+    ObjectCycle         => { Avoid => 1 },
+    Snapshots           => { Avoid => 1, List => 'Bag', Binary => 1 },
 );
 
 # Picture Licensing Universal System namespace properties (xmpPLUS)
@@ -1160,9 +1214,13 @@ my %sSubVersion = (
     %xmpTableDefaults,
     GROUPS => { 1 => 'XMP-xmpPLUS', 2 => 'Author' },
     NAMESPACE => 'xmpPLUS',
-    NOTES => 'XMP Picture Licensing Universal System (PLUS) namespace tags.',
-    CreditLineReq   => { Writable => 'boolean' },
-    ReuseAllowed    => { Writable => 'boolean' },
+    NOTES => q{
+        XMP Picture Licensing Universal System (PLUS) tags as written by some older
+        Adobe applications.  See L<PLUS XMP Tags|Image::ExifTool::TagNames/PLUS XMP Tags>
+        for the current PLUS tags.
+    },
+    CreditLineReq   => { Writable => 'boolean', Avoid => 1 },
+    ReuseAllowed    => { Writable => 'boolean', Avoid => 1 },
 );
 
 # Creative Commons namespace properties (cc) (ref 5)
@@ -1302,6 +1360,7 @@ my %sSubVersion = (
     PickLabel              => { },
     ImageHistory           => { Avoid => 1, Notes => 'different format from EXIF:ImageHistory' },
     LensCorrectionSettings => { },
+    ImageUniqueID          => { Avoid => 1 },
 );
 
 # SWF namespace tags (ref PH)
@@ -1362,6 +1421,11 @@ my %sSubVersion = (
     Curve4y    => { Writable => 'real' },
     Shadows    => { Writable => 'real', Avoid => 1 },
     Highlights => { Writable => 'real', Avoid => 1 },
+    # the following from StarGeek
+    FaceBalanceOrigI    => { Writable => 'real' },
+    FaceBalanceOrigQ    => { Writable => 'real' },
+    FaceBalanceStrength => { Writable => 'real' },
+    FaceBalanceWarmth   => { Writable => 'real' },
 );
 
 # Adobe creatorAtom properties (ref PH)
@@ -1450,25 +1514,26 @@ my %sSubVersion = (
     PoseHeadingDegrees              => { Writable => 'real' },
     PosePitchDegrees                => { Writable => 'real' },
     PoseRollDegrees                 => { Writable => 'real' },
-    InitialViewHeadingDegrees       => { Writable => 'integer' },
-    InitialViewPitchDegrees         => { Writable => 'integer' },
-    InitialViewRollDegrees          => { Writable => 'integer' },
+    InitialViewHeadingDegrees       => { Writable => 'real' },
+    InitialViewPitchDegrees         => { Writable => 'real' },
+    InitialViewRollDegrees          => { Writable => 'real' },
     InitialHorizontalFOVDegrees     => { Writable => 'real' },
     FirstPhotoDate                  => { %dateTimeInfo, Groups => { 2 => 'Time' } },
     LastPhotoDate                   => { %dateTimeInfo, Groups => { 2 => 'Time' } },
     SourcePhotosCount               => { Writable => 'integer' },
     ExposureLockUsed                => { Writable => 'boolean' },
-    CroppedAreaImageWidthPixels     => { Writable => 'integer' },
-    CroppedAreaImageHeightPixels    => { Writable => 'integer' },
-    FullPanoWidthPixels             => { Writable => 'integer' },
-    FullPanoHeightPixels            => { Writable => 'integer' },
-    CroppedAreaLeftPixels           => { Writable => 'integer' },
-    CroppedAreaTopPixels            => { Writable => 'integer' },
+    CroppedAreaImageWidthPixels     => { Writable => 'real' },
+    CroppedAreaImageHeightPixels    => { Writable => 'real' },
+    FullPanoWidthPixels             => { Writable => 'real' },
+    FullPanoHeightPixels            => { Writable => 'real' },
+    CroppedAreaLeftPixels           => { Writable => 'real' },
+    CroppedAreaTopPixels            => { Writable => 'real' },
+    InitialCameraDolly              => { Writable => 'real' },
     # (the following have been observed, but are not in the specification)
-    LargestValidInteriorRectLeft    => { Writable => 'integer' },
-    LargestValidInteriorRectTop     => { Writable => 'integer' },
-    LargestValidInteriorRectWidth   => { Writable => 'integer' },
-    LargestValidInteriorRectHeight  => { Writable => 'integer' },
+    LargestValidInteriorRectLeft    => { Writable => 'real' },
+    LargestValidInteriorRectTop     => { Writable => 'real' },
+    LargestValidInteriorRectWidth   => { Writable => 'real' },
+    LargestValidInteriorRectHeight  => { Writable => 'real' },
 );
 
 # Getty Images namespace (ref PH)
@@ -1478,12 +1543,65 @@ my %sSubVersion = (
     NAMESPACE => 'GettyImagesGIFT',
     NOTES => q{
         The actual Getty Images namespace prefix is "GettyImagesGIFT", which is the
-        prefix recorded in the file, but ExifTool shortens this for the "XMP-getty"
-        family 1 group name.
+        prefix recorded in the file, but ExifTool shortens this for the family 1
+        group name.
     },
-    Personality => { },
-    OriginalFilename => { Name => 'OriginalFileName' },
-    ParentMEID => { },
+    Personality         => { },
+    OriginalFilename    => { Name => 'OriginalFileName' },
+    ParentMEID          => { },
+    # the following from StarGeek
+    AssetID             => { },
+    CallForImage        => { },
+    CameraFilename      => { },
+    CameraMakeModel     => { Avoid => 1 },
+    Composition         => { },
+    CameraSerialNumber  => { Avoid => 1 },
+    ExclusiveCoverage   => { },
+    GIFTFtpPriority     => { },
+    ImageRank           => { },
+    MediaEventIdDate    => { },
+    OriginalCreateDateTime => { %dateTimeInfo, Groups => { 2 => 'Time' }, Avoid => 1 },
+    ParentMediaEventID  => { },
+    PrimaryFTP          => { List => 'Bag' },
+    RoutingDestinations => { List => 'Bag' },
+    RoutingExclusions   => { List => 'Bag' },
+    SecondaryFTP        => { List => 'Bag' },
+    TimeShot            => { },
+);
+
+# Google Spherical Images namespace (ref https://github.com/google/spatial-media/blob/master/docs/spherical-video-rfc.md)
+%Image::ExifTool::XMP::GSpherical = (
+    %xmpTableDefaults,
+    WRITABLE => 0,
+    GROUPS => { 1 => 'XMP-GSpherical', 2 => 'Image' },
+    NAMESPACE => 'GSpherical',
+    NOTES => q{
+        Not actually XMP.  These RDF/XML tags are used in Google spherical MP4
+        videos.  See
+        L<https://github.com/google/spatial-media/blob/master/docs/spherical-video-rfc.md>
+        for the specification.
+    },
+    Spherical                   => { },
+    Stitched                    => { },
+    StitchingSoftware           => { },
+    ProjectionType              => { },
+    StereoMode                  => { },
+    SourceCount                 => { },
+    InitialViewHeadingDegrees   => { },
+    InitialViewPitchDegrees     => { },
+    InitialViewRollDegrees      => { },
+    Timestamp                   => {
+        Name => 'TimeStamp',
+        Groups => { 2 => 'Time' },
+        ValueConv => 'ConvertUnixTime($val)', #(NC)
+        PrintConv => '$self->ConvertDateTime($val)',
+    },
+    FullPanoWidthPixels         => { },
+    FullPanoHeightPixels        => { },
+    CroppedAreaImageWidthPixels => { },
+    CroppedAreaImageHeightPixels=> { },
+    CroppedAreaLeftPixels       => { },
+    CroppedAreaTopPixels        => { },
 );
 
 # SVG namespace properties (ref 9)
@@ -1566,6 +1684,8 @@ under the same terms as Perl itself.
 
 =item L<http://www.portfoliofaq.com/pfaq/v7mappings.htm>
 
+=item L<http://www.iptc.org/IPTC4XMP/>
+
 =item L<http://creativecommons.org/technology/xmp>
 
 =item L<http://www.optimasc.com/products/fileid/xmp-extensions.pdf>
